Learn R Programming

bodenmiller (version 0.1.1)

refAnnots: Reference Annotation

Description

A data.frame containing the source file and cell type for every cell in refPhenoMat and refFuncMat. See Bodenmiller et al 2012 for details.

Usage

refAnnots

Arguments

Format

a data.frame with 15792 rows and 2 variables:

  • Sourcethe name of the source (fcs) file

  • Cellsthe cell type for the corresponding row in refPhenoMat or refFuncMat